from dataclasses import dataclass
from typing import List, Optional

from pygrype.core.decorators.to_json import to_json

@dataclass
@to_json
class MatchDetailsFound:
    vulnerabilityID: str
    versionConstraint: str
    cpes: Optional[List[str]]



from dataclasses import dataclass
from typing import Optional

from pygrype.core.decorators.to_json import to_json

@dataclass
@to_json
class Location:
    path: str
    layerID: Optional[str] = None



from dataclasses import dataclass
from typing import List, Optional

from pygrype.core.decorators.to_json import to_json

@dataclass
@to_json
class Distro:
    name: str
    version: str
    idLike: Optional[List]



from dataclasses import dataclass
from typing import List

from pygrype.core.decorators.to_json import to_json
from pygrype.core.scan.distro import Distro
from pygrype.core.scan.match import Match
from pygrype.core.scan.scan_source import ScanSource

@dataclass
@to_json
class Scan:
    matches: List[Match]
    source: ScanSource
    distro: Distro
    # descriptor: GrypeScanDescriptor



from dataclasses import dataclass

from pygrype.core.decorators.to_json import to_json

@dataclass
@to_json
class CVSSMetrics:
    baseScore: float
    exploitabilityScore: float
    impactScore: float



from dataclasses import dataclass
from typing import Union

from pygrype.core.decorators.to_json import to_json
from pygrype.core.scan.target import Target


@dataclass
@to_json
class ScanSource:
    type: str
    target: Union[Target, str]



import json
from dataclasses import asdict
from typing import Type, TypeVar

T = TypeVar('T')

def to_json(cls: Type[T]) -> Type[T]:
    def to_json_func(self: T):
        return json.dumps(asdict(self))
    cls.to_json = to_json_func
    return cls
